@@ -4,6 +4,13 @@ namespace Illuminate\View\Compilers\Concerns;
 
 trait CompilesJson
 {
+    /**
+     * The default JSON encoding options.
+     *
+     * @var int
+     */
+    private $encodingOptions = JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_AMP | JSON_HEX_QUOT;
+
     /**
      * Compile the JSON statement into valid PHP.
      *
@@ -14,9 +21,9 @@ trait CompilesJson
     {
         $parts = explode(',', $this->stripParentheses($expression));
 
-        $options = $parts[1] ?? 0;
+        $options = trim($parts[1] ?? $this->encodingOptions);
 
-        $depth = $parts[2] ?? 512;
+        $depth = trim($parts[2] ?? 512);
 
         return "<?php echo json_encode($parts[0], $options, $depth) ?>";
     }
